#
# =====================================================
# @(#) QUERY                     7.2        1999-07-29
# =====================================================
# Changes in  7.2:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *


def install (session,options):
    """Installing XQuery tables
    """

    repmanCmd (session, 'INSTALLATION ON')

    repmanCmd (session, 'AUTOCOMMIT OFF')

    if not sqlOK (session, "EXISTS TABLE QUERYLIBRARY"):
        stopIfSqlNotOK (session, """CREATE TABLE QUERYLIBRARY
            (
            AUTHOR       SYSID          DEFAULT USERGROUP,
            COMMAND_NAME CHAR(18) ASCII DEFAULT ' ',
            CREATEDATE   DATE           DEFAULT DATE,
            CREATETIME   TIME           DEFAULT TIME,
            UPDATEDATE   DATE           DEFAULT DATE,
            UPDATETIME   TIME           DEFAULT TIME,
            STRLENGTH    FIXED(18),
            CODETYPE     CHAR(6)  ASCII,
            COMMAND      LONG     BYTE,
            CONSTRAINT QUERYLIBRARY_PK PRIMARY KEY(AUTHOR,COMMAND_NAME)
            ) INTERNAL""")
    else:
        if sqlOK (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'QUERYLIBRARY'
                AND COLUMNNAME = 'AUTHOR'
                AND LEN > 18)"""):
            stopIfSqlNotOK (session, """ALTER TABLE QUERYLIBRARY
                ALTER PRIMARY KEY(AUTHOR,COMMAND_NAME)""")
            stopIfSqlNotOK (session, """ALTER TABLE QUERYLIBRARY
                DROP OBJTYPE,BLK_KEY4,BLK_KEY5,BLK_KEY6,BLK_KEY7""")
            stopIfSqlNotOK (session, """ALTER TABLE QUERYLIBRARY
                MODIFY (AUTHOR       SYSID)""")

    stopIfSqlNotOK (session, "GRANT SELECT,UPDATE,INSERT,DELETE ON QUERYLIBRARY TO DOMAIN")
    stopIfSqlNotOK (session, "GRANT SELECT ON QUERYLIBRARY TO PUBLIC")

    createReplaceView (session, 'QUERYLIB', """AS SELECT *
                FROM QUERYLIBRARY
                WHERE author = USERGROUP
            WITH CHECK OPTION
            INTERNAL""")

    stopIfSqlNotOK (session, "GRANT SELECT,UPDATE,INSERT,DELETE ON QUERYLIB TO PUBLIC")

    if sqlRC (session, "EXISTS TABLE QU_USR_ACCS_QCM") != 0:
        stopIfSqlNotOK (session, """CREATE TABLE QU_USR_ACCS_QCM
            (
            GRANTEE      SYSID          DEFAULT USERGROUP,
            AUTHOR       SYSID          DEFAULT USERGROUP,
            COMMAND_NAME CHAR(18)ASCII  DEFAULT ' ',
            PRIV         CHAR(4) ASCII,
            CONSTRAINT QU_USR_ACCS_QCM_PK
            PRIMARY KEY(GRANTEE,AUTHOR,COMMAND_NAME)
            )
            INTERNAL""")
    else:
        if sqlRC (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'QU_USR_ACCS_QCM'
                AND COLUMNNAME = 'AUTHOR'
                AND LEN > 18""") != 0:
            stopIfSqlNotOK (session, """ALTER TABLE QU_USR_ACCS_QCM
                ALTER PRIMARY KEY(GRANTEE,AUTHOR,COMMAND_NAME)""")
            stopIfSqlNotOK (session, """ALTER TABLE QU_USR_ACCS_QCM
                DROP DEFOBJTYPE,BLK_KEY2,BLK_KEY3,BLK_KEY5,BLK_KEY6,BLK_KEY7,
                REFOBJTYPE,BLK_KEY11,BLK_KEY12,BLK_KEY13,BLK_KEY14,RELTYPE""")
            stopIfSqlNotErr (session, """ALTER TABLE QU_USR_ACCS_QCM
                MODIFY
                (GRANTEE      SYSID,
                AUTHOR       SYSID)""")

    stopIfSqlNotOK (session, "GRANT INSERT,DELETE,UPDATE,SELECT ON QU_USR_ACCS_QCM TO DOMAIN")

    createReplaceView (session, "QUERY_OWN", """AS SELECT *
            FROM QU_USR_ACCS_QCM
            WHERE author = USERGROUP AND grantee = USERGROUP
            WITH CHECK OPTION
            INTERNAL""")

    stopIfSqlNotOK (session, "GRANT INSERT,DELETE,UPDATE,SELECT ON QUERY_OWN TO PUBLIC")

    createReplaceView (session, "QUERY_GRANT", """AS SELECT *
            FROM QU_USR_ACCS_QCM
            WHERE author = USERGROUP AND grantee <> USERGROUP
            WITH CHECK OPTION
            INTERNAL""")

    stopIfSqlNotOK (session, "GRANT INSERT,DELETE,UPDATE,SELECT ON QUERY_GRANT TO PUBLIC")

    createReplaceView (session, "QUERY_CALL", """AS SELECT *
            FROM QU_USR_ACCS_QCM
            WHERE author <> USERGROUP
            AND grantee IN(USERGROUP,'PUBLIC')
            WITH CHECK OPTION
            INTERNAL""")

    stopIfSqlNotOK (session, "GRANT SELECT ON QUERY_CALL TO PUBLIC")

    if not sqlOK (session, "EXISTS TABLE QUHISTORY"):
        stopIfSqlNotOK (session, """CREATE TABLE QUHISTORY
            (
            OWNER        SYSID          DEFAULT 'USER'
            CONSTRAINT QUHISTORY_PK PRIMARY KEY,
            CODETYPE     CHAR(6)  ASCII,
            PREVREC      LONG     ASCII
            )
            INTERNAL""")
    else:
        if not sqlOK (session, """SELECT OWNER
                FROM SYSDD.COLUMNS
                WHERE OWNER = USER
                AND TABLENAME = 'QUHISTORY'
                AND COLUMNNAME = 'OWNER'
                AND LEN > 18 )"""):
            stopIfSqlNotOK (session, """ALTER TABLE QUHISTORY
                MODIFY (OWNER SYSID)""")

    stopIfSqlNotOK (session, "GRANT SELECT,UPDATE,INSERT,DELETE ON QUHISTORY TO DOMAIN")

    createReplaceView (session, "QUHIST", """AS SELECT *
            FROM QUHISTORY
            WHERE owner = USER
            WITH CHECK OPTION
            INTERNAL""")

    stopIfSqlNotOK (session, "GRANT INSERT,UPDATE,SELECT ON QUHIST TO PUBLIC")

    repmanCmd (session, 'COMMIT')

    repmanCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)


