#
# =====================================================
# @(#) SAP DB LOADER     7.3.0        21.06.2002
# =====================================================
#
#    ========== licence begin LGPL
#    Copyright (C) 2002 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *


def install (session,options):
    """Installing Loader tables
    """

    repmanCmd (session, 'INSTALLATION  ON')

    repmanCmd (session, 'AUTOCOMMIT OFF')

    # ********************************
    #  Table TRANSFORMATIONMODEL
    # ********************************

    dropTable (session, "TRANSFORMATIONMODEL")

    stopIfSqlNotOK (session,
    """
    CREATE TABLE TRANSFORMATIONMODEL (
    PACKAGEGUID         CHAR  (24)    BYTE                 ,
    TASKID          FIXED (6,0)   DEFAULT      0       ,
    SERVERNODE          CHAR  (32)    DEFAULT      NULL    ,
    SERVERDB            CHAR  (32)    DEFAULT      NULL    ,
    CODETYPE            CHAR  (32)    DEFAULT      NULL    ,
    USERNAME            CHAR  (32)    DEFAULT      NULL    ,
    CODEPAGEID          CHAR  (32)    DEFAULT      NULL    ,
    STORAGEDEVICE       CHAR  (32)    DEFAULT      NULL    ,
    TRANSACTIONSIZE             FIXED (6,0)   DEFAULT      0       ,
    TRANSFORMATION      CHAR  (32)    DEFAULT      NULL    ,
    PART            CHAR  (8)     DEFAULT      NULL    ,
    STEPID          FIXED (6,0)   DEFAULT      0       ,
    OWNER           CHAR  (32)             ,
    TABLENAME           CHAR  (32)                 ,
    TABLETYPE               CHAR  (8 )    ASCII                ,
    CATALOGSTREAMNAME       CHAR  (254)   DEFAULT      NULL    ,
    CATALOGSTREAMTYPE       CHAR  (32)    DEFAULT      NULL    ,
    CATALOGSTREAMFORMAT         CHAR  (32)    DEFAULT      NULL    ,
    DATASTREAMNAME      CHAR  (254)   DEFAULT      NULL    ,
    DATASTREAMTYPE      CHAR  (32)    DEFAULT      NULL    ,
    DATASTREAMFORMAT        CHAR  (32)    DEFAULT      NULL    ,
    DATASTREAMHEADERBLOCK       Fixed (6,0)   DEFAULT      0       ,
    DATASTREAMHEADERPOS         Fixed (10,0)  DEFAULT      0       ,
    DATASTREAMDATABLOCK         Fixed (6,0)   DEFAULT      0       ,
    DATASTREAMDATAPOS       Fixed (10,0)  DEFAULT      0       ,
    DATASTREAMTRAILERBLOCK      Fixed (6,0)   DEFAULT      0       ,
    DATASTREAMTRAILERPOS        Fixed (10,0)  DEFAULT      0       ,
    EXCLUDE         BOOLEAN       DEFAULT      FALSE   ,
    RESTART         BOOLEAN       DEFAULT      TRUE    ,
    RESTORE         BOOLEAN       DEFAULT      FALSE   ,
    PAGECOUNT           Fixed (10,0)  DEFAULT      0       ,
    ROWCOUNT            Fixed (10,0)  DEFAULT      0       ,
    STARTTIME           TIMESTAMP     DEFAULT      NULL    ,
    ENDTIME         TIMESTAMP     DEFAULT      NULL    ,
    REQUESTTIME         Fixed (15,10) DEFAULT      0       ,
    RECEIVETIME         Fixed (15,10) DEFAULT      0       ,
    IOTIME          Fixed (15,10) DEFAULT      0       ,
    LOGTIME         Fixed (15,10) DEFAULT      0       ,
    SEQ_NO          Fixed (6,0)   DEFAULT      0       ,
    CMD                         CHAR  (254)   ASCII                ,
    PRIMARY KEY ( PACKAGEGUID, TASKID, STEPID, OWNER, TABLENAME, SEQ_NO),
    CONSTRAINT "CODETYPE"            CHECK \"CODETYPE\"            IS NULL OR \"CODETYPE\"            IN ('ASCII'  , 'UNICODE'),
    CONSTRAINT "STORAGEDEVICE"       CHECK \"STORAGEDEVICE\"       IS NULL OR \"STORAGEDEVICE\"       IN ('NONE'   , 'TSM' , 'OMNIBACK', 'NETWORKER' ) ,
    CONSTRAINT "TRANSFORMATION"      CHECK \"TRANSFORMATION\"      IS NULL OR \"TRANSFORMATION\"      IN ('EXTRACT', 'LOAD', 'UPDATE' ) ,
    CONSTRAINT "PART"                CHECK \"PART\"                IS NULL OR \"PART\"                IN ('ALL'    , 'USER', 'TABLE'  ) ,
    CONSTRAINT "TABLETYPE"           CHECK \"TABLETYPE\"           IS NULL OR \"TABLETYPE\"           IN ('TABLE'  , 'VIEW', 'SYNONYM') ,
    CONSTRAINT "CATALOGSTREAMTYPE"   CHECK \"CATALOGSTREAMTYPE\"   IS NULL OR \"CATALOGSTREAMTYPE\"   IN ('FILE'   , 'PIPE', 'TAPE'   ) ,
    CONSTRAINT "CATALOGSTREAMFORMAT" CHECK \"CATALOGSTREAMFORMAT\" IS NULL OR \"CATALOGSTREAMFORMAT\" IN ('DDL'    , 'XML' ) ,
    CONSTRAINT "DATASTREAMTYPE"      CHECK \"DATASTREAMTYPE\"      IS NULL OR \"DATASTREAMTYPE\"      IN ('FILE'   , 'PIPE', 'TAPE' ) ,
    CONSTRAINT "DATASTREAMFORMAT"    CHECK \"DATASTREAMFORMAT\"    IS NULL OR \"DATASTREAMFORMAT\"    IN ('PAGES'  , 'RECORDS', 'COMPRESSED', 'FORMATTED' )
    )
    INTERNAL
    """)

    # grant on TRANSFORMATIONMODEL
    stopIfSqlNotOK (session, 'GRANT SELECT,INSERT,UPDATE,DELETE ON TRANSFORMATIONMODEL TO PUBLIC')

    #comments on TRANSFORMATIONMODEL columns
    stopIfSqlNotOK (session, """COMMENT ON TABLE  TRANSFORMATIONMODEL IS ' ' """)
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.PACKAGEGUID IS 'Unique Identifier of the TransformationPackage ' """)
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.TASKID IS 'TransformationTask Identifier '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.SERVERNODE IS 'Node of the Database to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.SERVERDB IS 'Name of the Database to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CODETYPE IS 'Encoding type of the Database to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.USERNAME IS 'Name of User running Loader Session '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CODEPAGEID IS 'Identifier of a ASCII Codepage associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.STORAGEDEVICE IS 'External StorageDevice associated to Loader Session '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.TRANSACTIONSIZE IS 'Number of Records that are transformed within a transaction  '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.TRANSFORMATION IS 'TransformationType '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.PART IS 'TransformationPart '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.STEPID IS 'TransformationStep Identifier'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.OWNER IS 'Owner of TableType to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.TABLENAME IS 'Name of TableType to transform'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.TABLETYPE IS 'TableType to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CATALOGSTREAMNAME IS 'Identifier of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CATALOGSTREAMTYPE IS 'DeviceType of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CATALOGSTREAMFORMAT IS 'Format of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMNAME IS 'Identifier of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMTYPE IS 'Type of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMFORMAT IS 'Format of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMHEADERBLOCK IS 'StartPosition of DataStreamHeader counted in 2 GB Blocks '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMHEADERPOS IS 'StartPosition of DataStreamHeader counted in Bytes less than 2 GB '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMDATABLOCK IS 'StartPosition of DataStreamData counted in 2 GB Blocks '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMDATAPOS IS 'StartPosition of DataStreamData counted in Bytes less than 2 GB '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMTRAILERBLOCK IS 'StartPosition of DataStreamTrailer counted in 2 GB Blocks '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.DATASTREAMTRAILERPOS IS 'StartPosition of DataStreamTrailer counted in Bytes less than 2 GB '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.EXCLUDE IS 'TransformationStep excluded '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.RESTART IS 'TransformationStep succeeded '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.RESTORE IS 'Transform TransformationStep to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.PAGECOUNT IS 'Number of Pages transformed by a TransformationStep '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.ROWCOUNT IS 'Number of Rows transformed by a TransformationStep'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.STARTTIME IS 'StartTime of TransformationStep '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.ENDTIME IS 'EndTime of TransformationStep '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.REQUESTTIME IS 'Total execution time of kernel requests within a TransformationStep '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.RECEIVETIME IS 'Total execution time of kernel receives within a TransformationStep '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.IOTIME  IS 'Total iotime within a TransformationStep'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.LOGTIME IS 'Total logtime within a TransformationStep'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.SEQ_NO IS 'Authorization statement exceeding a columnwidth '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONMODEL.CMD IS 'Authorization statement '""")

    # ********************************
    #  Table CodePage
    # ********************************

    dropTable (session, "CODEPAGE")

    stopIfSqlNotOK (session,
    """
    CREATE TABLE \"CODEPAGE\" (
    CODEPAGEID                  CHAR (32)                  NOT NULL,
    CODEPAGETABLE               CHAR (512)    BYTE         NOT NULL,
    PRIMARY KEY (CODEPAGEID)) INTERNAL
    """)

    # ********************************
    #  DBPROC TRANSFORMATIONPACKAGE
    # ********************************
    #dropDBProc (session, "TRANSFORMATIONPACKAGE")

    rc = sqlRC (session, """SELECT DBPROCEDURE FROM SYSDD.DBPROCEDURES WHERE DBPROCEDURE = 'TRANSFORMATIONPACKAGE'""")
    if rc == 0:
        stopIfSqlNotOK(session, """DROP DBPROC \"TRANSFORMATIONPACKAGE\"""")

    stopIfSqlNotOK (session,"""
    CREATE DBPROC SYSDBA.TRANSFORMATIONPACKAGE ( IN packageguid CHAR(24) BYTE )
    AS
    VAR  rc INTEGER; errmsg CHAR(80);
         task_id  FIXED(6,0);step_id  FIXED(6,0); temp_step_id FIXED(6,0); seq_no FIXED(6,0); owner CHAR(32); tablename CHAR(32);
         step_id_ FIXED(6,0);
    TRY
    SET    rc = 0;
    SET    task_id = 0; SET  step_id_ = 0; SET  temp_step_id = 0;

    SELECT MAX(TASKID)+1,STEPID, SEQ_NO, OWNER, TABLENAME
           FROM SYSDBA.TRANSFORMATIONMODEL
           GROUP BY STEPID, SEQ_NO, OWNER, TABLENAME
           ORDER BY STEPID, SEQ_NO  ASC ;

    WHILE $rc = 0 DO
              BEGIN
             FETCH INTO :task_id, :step_id, :seq_no, :owner, :tablename;
                      IF step_id = temp_step_id  THEN
                         SET step_id_ = step_id_
                      ELSE
                         SET step_id_ = step_id_+1;
              UPDATE SYSDBA.TRANSFORMATIONMODEL
                      SET    TASKID = :task_id ,
                             STEPID = :step_id_,
                             SEQ_NO = :seq_no
                      WHERE  PACKAGEGUID = :packageguid AND
                             OWNER       = :owner       AND TABLENAME   = :tablename AND
                             STEPID      = :step_id     AND SEQ_NO      = :seq_no    AND
                             TASKID      = 0 ;
                SET temp_step_id = step_id;
            END;
    CATCH
       IF $rc <> 100 THEN
          STOP ($rc, 'Unexpected error');
    """)

    #comments on SP_TRANSFORMATIONMODEL
    stopIfSqlNotOK (session, """COMMENT ON DBPROC SYSDBA.TRANSFORMATIONPACKAGE IS 'Initializes the TransformationPackage of the TRANSFORMATIONMODEL ' """)

    #grant DBPROC TRANSFORMATIONPACKAGE to PUBLIC
    stopIfSqlNotOK (session, 'GRANT EXECUTE ON SYSDBA.TRANSFORMATIONPACKAGE TO PUBLIC')

    # ********************************
    #  View TRANSFORMATIONPACKAGES
    # ********************************

    stopIfSqlNotOK (session,"""
    CREATE OR REPLACE VIEW TRANSFORMATIONPACKAGES AS
    SELECT PACKAGEGUID,TASKID,STEPID,OWNER,TABLENAME,EXCLUDE,RESTART
    FROM TRANSFORMATIONMODEL
    WHERE TABLETYPE = 'TABLE' AND CMD NOT LIKE 'GRANT *' OR CMD IS NULL
    INTERNAL
    """)

    # grant on TRANSFORMATIONPACKAGES
    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSFORMATIONPACKAGES TO PUBLIC')

    #comments on TRANSFORMATIONPACKAGES columns
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.PACKAGEGUID IS 'Unique Identifier of the TransformationPackage ' """)
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.TASKID IS 'TransformationTask Identifier '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.STEPID IS 'TransformationStep Identifier'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.OWNER IS 'Name of Schema that owns TableTypes '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.TABLENAME IS 'Name of TableType to transform'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.EXCLUDE IS 'TransformationStep excluded '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONPACKAGES.RESTART IS 'TransformationStep succeeded '""")

    # ********************************
    #  View TRANSFORMATIONSTEPS
    # ********************************

    stopIfSqlNotOK (session,"""
    CREATE OR REPLACE VIEW TRANSFORMATIONSTEPS AS
    SELECT PACKAGEGUID,TRANSFORMATION,OWNER,TABLENAME,CATALOGSTREAMNAME,CATALOGSTREAMFORMAT,DATASTREAMNAME,DATASTREAMFORMAT,DATASTREAMHEADERBLOCK,DATASTREAMHEADERPOS,DATASTREAMDATABLOCK,DATASTREAMDATAPOS,DATASTREAMTRAILERBLOCK,DATASTREAMTRAILERPOS,RESTART,ROWCOUNT AS START
    FROM TRANSFORMATIONMODEL
    WHERE EXCLUDE = FALSE AND TABLETYPE = 'TABLE' AND ( CMD NOT LIKE 'GRANT *' OR CMD IS NULL )
    INTERNAL
    """)

    # grant on TRANSFORMATIONSTEPS
    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSFORMATIONSTEPS TO PUBLIC')

    #comments on TRANSFORMATIONSTEPS columns
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.PACKAGEGUID IS 'Unique Identifier of the TransformationPackage ' """)
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.TRANSFORMATION IS 'TransformationType '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.OWNER IS 'Name of Schema that owns TableTypes '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.TABLENAME IS 'Name of TableType to transform'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.CATALOGSTREAMNAME IS 'Identifier of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.CATALOGSTREAMFORMAT IS 'Format of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMNAME IS 'Identifier of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMFORMAT IS 'Format of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMHEADERBLOCK IS 'StartPosition of DataStreamHeader counted in 2 GB Blocks '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMHEADERPOS IS 'StartPosition of DataStreamHeader counted in Bytes less than 2 GB '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMDATABLOCK IS 'StartPosition of DataStreamData counted in 2 GB Blocks  '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMDATAPOS IS 'StartPosition of DataStreamData counted in Bytes less than 2 GB  '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMTRAILERBLOCK IS 'StartPosition of DataStreamTrailer counted in 2 GB Blocks '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.DATASTREAMTRAILERPOS IS 'StartPosition of DataStreamTrailer counted in Bytes less than 2 GB '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.RESTART IS 'TransformationStep succeeded '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONSTEPS.START IS 'Number of transformed Rows'""")


    # ********************************
    #  View TRANSFORMATIONRESOURCES
    # ********************************

    stopIfSqlNotOK (session,"""
    CREATE OR REPLACE VIEW TRANSFORMATIONRESOURCES AS
    SELECT DISTINCT PACKAGEGUID, SERVERNODE,SERVERDB,USERNAME ,CODEPAGEID, STORAGEDEVICE, CATALOGSTREAMNAME,CATALOGSTREAMTYPE,DATASTREAMNAME,DATASTREAMTYPE
    FROM TRANSFORMATIONMODEL
    WHERE EXCLUDE = FALSE
    INTERNAL
    """)

    # grant on TRANSFORMATIONRESOURCES
    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSFORMATIONRESOURCES TO PUBLIC')

    #comments on TRANSFORMATIONRESOURCES columns
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.PACKAGEGUID IS 'Unique Identifier of the TransformationPackage ' """)
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.SERVERNODE IS 'Node of the Database to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.SERVERDB IS 'Name of the Database to transform '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.CODEPAGEID IS 'Identifier of a ASCII Codepage associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.USERNAME IS 'Schema of the Database to transform'""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.STORAGEDEVICE IS 'External StorageDevice associated to Loader Session '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.CATALOGSTREAMNAME IS 'Identifier of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.CATALOGSTREAMTYPE IS 'Type of CatalogStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.DATASTREAMNAME IS 'Identifier of DataStream associated to Loader Command '""")
    stopIfSqlNotOK (session, """COMMENT ON COLUMN TRANSFORMATIONRESOURCES.DATASTREAMTYPE IS 'Type of DataStream associated to Loader Command  '""")


    # ********************************
    #  View TRANSFORMATIONSTATISTIC
    # ********************************

    stopIfSqlNotOK (session,"""
    CREATE OR REPLACE VIEW TRANSFORMATIONSTATISTIC AS
    SELECT PACKAGEGUID, STEPID, OWNER,TABLENAME, DATASTREAMTRAILERPOS-DATASTREAMHEADERPOS AS BYTECOUNT,ROWCOUNT, (HOUR (ENDTIME) - HOUR (STARTTIME)) *3600000 + (MINUTE (ENDTIME) - MINUTE (STARTTIME)) *60000 + (SECOND (ENDTIME) - SECOND (STARTTIME)) *1000 + ((MICROSECOND (ENDTIME) - MICROSECOND (STARTTIME)) /1000) AS SYSTEMTIME, (REQUESTTIME+RECEIVETIME) *1000 AS KERNELTIME, (HOUR (ENDTIME) - HOUR (STARTTIME)) *3600000 + (MINUTE (ENDTIME) - MINUTE (STARTTIME)) *60000 + (SECOND (ENDTIME) - SECOND (STARTTIME)) *1000 + ((MICROSECOND (ENDTIME) - MICROSECOND (STARTTIME)) /1000) - (REQUESTTIME+RECEIVETIME)*1000 AS LOADERTIME, (HOUR (ENDTIME) - HOUR (STARTTIME)) *3600000 + (MINUTE (ENDTIME) - MINUTE (STARTTIME)) *60000 + (SECOND (ENDTIME) - SECOND (STARTTIME)) *1000 + ((MICROSECOND (ENDTIME) - MICROSECOND (STARTTIME)) /1000) - (REQUESTTIME+RECEIVETIME)*1000 - (IOTIME) *1000 - (LOGTIME) *1000 AS DATATIME, (LOGTIME)*1000 AS LOGTIME, (IOTIME) *1000 AS IOTIME
    FROM TRANSFORMATIONMODEL
    WHERE EXCLUDE = FALSE AND RESTART = FALSE AND TABLETYPE = 'TABLE' AND ( CMD NOT LIKE 'GRANT *' OR CMD IS NULL )
    INTERNAL
    """)

    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSFORMATIONSTATISTIC TO PUBLIC')

    # ********************************
    #  View TRANSFORMATIONMONITOR
    # ********************************

    stopIfSqlNotOK (session,"""
    CREATE OR REPLACE VIEW TRANSFORMATIONMONITOR AS
    SELECT PACKAGEGUID,COUNT(*) AS TABLECOUNT, SUM(ROWCOUNT) AS ROWCOUNT, SUM(SYSTEMTIME) AS SYSTEMDURATION, SUM(KERNELTIME) AS KERNELDURATION, SUM(LOADERTIME) AS LOADERDURATION, SUM(DATATIME) AS DATADURATION, SUM(LOGTIME) AS LOGDURATION, SUM(IOTIME) AS IODURATION
    FROM TRANSFORMATIONSTATISTIC
    GROUP BY PACKAGEGUID
    INTERNAL
    """)

    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSFORMATIONMONITOR TO PUBLIC')

    repmanCmd  (session, 'COMMIT')

    repmanCmd  (session, 'INSTALLATION OFF')


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)

