#
# =====================================================
# @(#) SYSDBA                     7.2        1999-07-29
# =====================================================
# Changes in  7.2:
#        - EXTRACT_EXCEPTIONS not installed
#        - UTILITY_COMMANDS not installed
#        - no questioning on UNICODE parameter
#        - switched diagnose monitor/analyze off (PTS 1105556)
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#

from installib import *

def install (session,options):
    """Installing SYSDBA tables
    """

    repmanCmd (session, 'INSTALLATION ON')
    repmanCmd (session, 'AUTOCOMMIT OFF')

    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_CACHES')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_LOAD')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_LOCK')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_LOG')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_LONG')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_PAGES')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_ROW')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_TRANS')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_VTRACE')

    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_SNAPSHOT')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MONITOR_SNAPSHOT')
    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_SNAPSHOT')
    stopIfSqlNotErr (session, -4004, 'DROP VIEW MON_SERVERDB')
    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_SERVERDB')


    rc = sqlRC (session, 'DROP TABLE SYS_UPDSTATISTICS')
    if rc != 0:
	if rc == -8015:
            stopIfSqlNotErr (session, -4004, 'DROP VIEW SYS_UPDSTATISTICS')

        else:
            if rc != -4004:
                stopInstall(session, rc)


    rc = sqlRC (session, """SELECT DESCRIPTION
        FROM SYSDD.XPARAMETERS
        WHERE DESCRIPTION = '_UNICODE'
        AND "VALUE" = 'YES'""")

    if rc == 0:

        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSID CHAR(32) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSQPNAME CHAR(75) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSCOMMENT CHAR(1000) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSMSGTEXT CHAR(80) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSLONG LONG UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSJOB CHAR(20) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSSTATEMENT CHAR(3900) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSDATATYPE CHAR(6) UNICODE')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSDATA CHAR(2000) UNICODE')

    else:
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSID CHAR(64) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSQPNAME CHAR(150) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSCOMMENT CHAR(2000) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSMSGTEXT CHAR(160) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSLONG LONG ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSJOB CHAR(40) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSSTATEMENT CHAR(7800) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSDATATYPE CHAR(12) ASCII')
        stopIfSqlNotErr (session, -6006, 'CREATE DOMAIN SYSDATA CHAR(4000) ASCII')

    repmanCmd (session, 'DIAGNOSE MONITOR PARSEID OFF')
    repmanCmd (session, 'DIAGNOSE MONITOR OFF')
    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSPARSEID')
    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSMONITOR')
    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSMONDATA')

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSPARSEID
        ("PARSEID" CHAR(12) BYTE,
         LINKAGE FIXED(1),
         SELECT_PARSEID CHAR(12) BYTE,
         OWNER SYSID,
         SQL_STATEMENT SYSSTATEMENT,
         JOB SYSJOB,
         LINE FIXED(10),
         CONSTRAINT  SYSP_PK
         PRIMARY KEY("PARSEID",LINKAGE)) INTERNAL """)

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSMONITOR
        (SYSK CHAR(8) BYTE,
         LINKAGE CHAR(1) BYTE,
         "PARSEID" CHAR(12) BYTE,
         ROWS_READ FIXED(20),
         ROWS_QUAL FIXED(20),
         VIRTUAL_READS FIXED(20),
         SUBREQUESTS FIXED(20),
         STRATEGY CHAR(40) ASCII,
         RUNTIME FIXED(20,6),
         VWAITS FIXED(20),
         VSUSPENDS FIXED(20),
         PHYSICAL_IO FIXED(20),
         ROWS_FETCHED FIXED (20),
         FETCH_CALLS FIXED (20),
         ROOT1 FIXED(10),
         ROOT2 FIXED(10),
         ROOT3 FIXED(10),
         ROOT4 FIXED(10),
         ROOT5 FIXED(10),
         ROOT6 FIXED(10),
         RESULT_COPIED CHAR(3) ASCII,
         DATETIME TIMESTAMP,
         TERMID CHAR(18) ASCII,
         USERNAME SYSID,
         APPL_PROCESS FIXED(10),
         APPL_NODE CHAR(64) ASCII,
         CONSTRAINT SYSMONITOR_PK
         PRIMARY KEY (SYSK, LINKAGE)) INTERNAL """)

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSMONDATA
        (SYSK CHAR(8) BYTE,
         PARAMNO FIXED(5),
         DATA_TYPE SYSDATATYPE,
         DATA SYSDATA,
         CONSTRAINT SYSMONDATA_PK
         PRIMARY KEY (SYSK,PARAMNO)) INTERNAL """)

    repmanCmd (session, 'DIAGNOSE ANALYZE OFF')
    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSCMD_ANALYZE')
    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSDATA_ANALYZE')

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSCMD_ANALYZE
        (JOB  SYSJOB,
         LINE FIXED(10),
         CMDID CHAR(8) BYTE,
         LINKAGE FIXED(1),
         SQL_STATEMENT SYSSTATEMENT,
         CMDHASH FIXED(10),
         HASHLISTPOS FIXED(5),
         CONSTRAINT SYSCMD_ANALYZE_PK
         PRIMARY KEY (JOB,LINE,CMDHASH,LINKAGE,HASHLISTPOS)) INTERNAL """)

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSDATA_ANALYZE
        (CMDID CHAR(8) BYTE,
         SESSION CHAR (4) BYTE,
         CALL_COUNT FIXED(20),
         ROWS_READ FIXED(20),
         ROWS_QUAL FIXED(20),
         VIRTUAL_READS FIXED(20),
         RUNTIME FIXED(20,6),
         MIN_RUNTIME FIXED(20,6),
         MAX_RUNTIME FIXED (20,6),
         VWAITS FIXED (20),
         VSUSPENDS FIXED(20),
         PHYSICAL_IO FIXED(20),
         ROWS_FETCHED FIXED(20),
         CONSTRAINT  SYSDATA_ANALYZEPK PRIMARY KEY (CMDID, SESSION)) INTERNAL """)

    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSACCOUNT')

    stopIfSqlNotOK (session,
	"""CREATE TABLE SYSACCOUNT
	(SERVERDB_NO        FIXED (4),
	 SESSION            FIXED(18),
	 NOLOG_SESSION      CHAR(3) ASCII,
	 USERNAME           SYSID,
	 GROUPNAME          SYSID,
	 TERMID             VARCHAR(18) ASCII,
	 DBANAME            SYSID,
	 CONNECTDATE        DATE,
	 CONNECTTIME        TIME,
	 RELEASEDATE        DATE,
	 RELEASETIME        TIME,
	 COMMANDCOUNT       FIXED(10),
	 CPUTIME            FIXED(10),
	 DATA_CACHE_ACCESS  FIXED(18),
	 SESSIONEND         CHAR(8) ASCII,
	 PROGTYPE           VARCHAR(8) ASCII,
	 PROGOWNER          SYSID,
	 PROGNAME           SYSID,
	 CATALOG_CACHE_SIZE INTEGER,
	 CAT_CACHE_HITRATE  FIXED(4),
	 DBPROC_CACHE_SIZE  INTEGER,
	 TEMP_SIZE_CACHE    INTEGER,
	 TEMP_HITRATE_CACHE FIXED(4)
	)
 	INTERNAL""")

    stopIfSqlNotErr (session, -6000,
	"""CREATE TABLE SYSCHECKTABLELOG
	(OWNER        SYSID,
	 TABLENAME    SYSID,
	 EXCECUTED_AT TIMESTAMP,
	 MSGNO        FIXED(5)
	)
 	INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON SYSCHECKTABLELOG TO PUBLIC')

    stopIfSqlNotErr (session, -6000,
	"""CREATE TABLE SYSERRORMAP
	(MAPMSGNO      FIXED(5,0),
	 MAPID         CHAR(3)     ASCII,
	 MAPPEDMSGNO   FIXED(5,0),
	 MAPTOKENINDEX FIXED(5,0),
	 PRIMARY KEY (MAPMSGNO,MAPID)
	)
	INTERNAL""")

    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSUPDSTATWANTED')

    stopIfSqlNotOK (session,
        """CREATE TABLE SYSUPDSTATWANTED
	(OWNER      SYSID,
	 TABLENAME  SYSID,
	 COLUMNNAME SYSID,
	 PRIMARY KEY (OWNER, TABLENAME, COLUMNNAME)
	)
	INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT ALL ON SYSUPDSTATWANTED TO PUBLIC')

    stopIfSqlNotErr (session, -6000,
        """CREATE VIEW SYS_UPDSTATISTICS AS
        SELECT OWNER, TABLENAME, COLUMNNAME
        FROM SYSUPDSTATWANTED
        WHERE COLUMNNAME <> ' '
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT ALL ON SYS_UPDSTATISTICS TO PUBLIC')



    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSSTATISTICS')

    stopIfSqlNotErr (session, -6000,
        """CREATE TABLE SYSSTATISTICS
        (OWNER           SYSID,
	     TABLENAME       SYSID,
	     COLUMNNAME      SYSID,
	     INDEXNAME       SYSID,
	     PAGES           FIXED(10),
	     DISTINCT_VALUES FIXED(10),
	     AVG_LIST_LEN    FIXED(10,1)
        ) INTERNAL """)


    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYSUPDSTATLOG')



    stopIfSqlNotErr (session, -6000,
        """CREATE TABLE SYSUPDSTATLOG
        (OWNER           SYSID,
         TABLENAME       SYSID,
         TABLEID         CHAR(8) BYTE,
         COLUMNNAME      SYSID,
         INDEXNAME       SYSID,
         EXECUTED_AT     TIMESTAMP,
         IMPLICIT        CHAR(3) ASCII,
         SAMPLE_PCT      FIXED(3),
         SAMPLE_ROW      FIXED(10),
         EXECUTION_START TIMESTAMP,
         EXECUTION_END   TIMESTAMP,
         SESSION         FIXED(10),
         TERMID          CHAR(18) ASCII,
         PAGES_KNOWN     FIXED(10),
         PAGES_FOUND     FIXED(10),
         SEQNO           FIXED(5),
         PRIMARY KEY (OWNER, TABLENAME, SEQNO)
        ) INTERNAL """)


    stopIfSqlNotErr (session, -6000,
        """CREATE TABLE "SYS%CAT1"
        (K    CHAR(48)   BYTE,
         INFO CHAR(3900) BYTE,
         PRIMARY KEY (K)
         )
        INTERNAL""")


    stopIfSqlNotErr (session, -6000,
        """CREATE TABLE "SYS%CAT2"
        (K    CHAR(48)   BYTE,
         INFO CHAR(3900) BYTE,
         PRIMARY KEY (K)
         )
         INTERNAL""")


    stopIfSqlNotErr (session, -4004, 'DROP TABLE SYS_PACKAGE')




    rc = sqlRC (session, 'EXISTS TABLE DUAL')

    if rc != 0:
        stopIfSqlNotOK (session,
            'CREATE TABLE DUAL (DUMMY CHAR(1) ASCII) INTERNAL')

        stopIfSqlNotOK (session,
            """INSERT INTO DUAL VALUES ('a')""")

        stopIfSqlNotOK (session,
            """GRANT SELECT ON DUAL TO PUBLIC WITH GRANT OPTION""")




    stopIfSqlNotErr (session, -4004, 'DROP VIEW OPTIMIZERSTATISTIC')

    createReplaceView ( session, 'OPTIMIZERSTATISTICS',
        """(OWNER,TABLENAME,INDEXNAME,COLUMNNAME,
           DISTINCTVALUES,PAGECOUNT,AVGLISTLENGTH)
        AS SELECT
             OWNER,TABLENAME,INDEXNAME,COLUMNNAME,
             DISTINCTVALUES,PAGECOUNT,AVGLISTLENGTH
           FROM SYSDD.OPTIMIZER_STATS
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON OPTIMIZERSTATISTICS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'CONFIGURATION',
        """(DESCRIPTION,CHAR_VALUE,NUMERIC_VALUE)
        AS SELECT
             DESCRIPTION,"VALUE",NUMERIC_VALUE
           FROM SYSDD.CONFIGURATION
           WHERE USER IN(SELECT USERNAME
                         FROM SYSDD.USERS
                         WHERE USERNAME = USERGROUP
                         AND USERMODE IN('DBA','SYSDBA','COLDUSER'))
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON CONFIGURATION TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'DATADEVSPACES',
        """(DEVSPACENAME,DEVSPACESIZE,
           USEDPAGES,PCTUSEDPAGES,
           UNUSEDPAGES,PCTUNUSED)
        AS SELECT
             DEVSPACENAME,PAGES,
             USED_PAGES,PCT_USED_PAGES,
             UNUSED_PAGES,PCT_PAGES_UNUSED
          FROM SYSDD.DEVSPACESTATISTICS
          WHERE USER IN(SELECT USERNAME
                        FROM SYSDD.USERS
                        WHERE USERNAME = USERGROUP
                        AND USERMODE IN('DBA','SYSDBA','COLDUSER'))
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON DATADEVSPACES TO PUBLIC WITH GRANT OPTION')
    createReplaceView (session, 'INDEXSTATISTICS',
        """(OWNER,TABLENAME,INDEXNAME,COLUMNNAME,
           DESCRIPTION,CHAR_VALUE,NUMERIC_VALUE)
        AS SELECT
             OWNER,TABLENAME,INDEXNAME,COLUMNNAME,
             DESCRIPTION,"VALUE",NUMERIC_VALUE
           FROM SYSDD.INDEXSTATISTICS
           WHERE OWNER = USERGROUP OR USER = SYSDBA
        INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON INDEXSTATISTICS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'LOCKSTATISTICS',
        """(SESSION, TRANSCOUNT, PROCESS, USERNAME, "DATE", "TIME",
           TERMID, REQTIMEOUT,
           LASTWRITE, LOCKMODE, LOCKSTATE, REQMODE, REQSTATE,
           APPLPROCESS, APPLNODE, OWNER, TABLENAME, TABLEID,
           ROWIDLENGTH, ROWIDHEX, "ROWID")
        AS SELECT
             SESSION, TRANSCOUNT, PROCESS, USERNAME, "DATE", "TIME",
             TERMID, REQ_TIMEOUT,
             LAST_WRITE, LOCK_MODE, LOCK_STATE, REQ_MODE, REQ_STATE,
             APPL_PROCESS, APPL_NODEID, OWNER, TABLENAME, TABLEID,
             ROWID_LENGTH, ROWID_HEX, "ROWID"
           FROM SYSDD.LOCKS
           WHERE USERNAME = USERGROUP OR OWNER = USERGROUP
           OR USERGROUP IN(SELECT USERNAME
                           FROM SYSDD.USERS
                           WHERE USERMODE IN('DBA', 'SYSDBA', 'COLDUSER')
                           AND USERNAME = USERGROUP)
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON LOCKSTATISTICS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'LOCKLISTSTATISTICS',
        """(DESCRIPTION, "VALUE")
            AS SELECT
            DESCRIPTION, "VALUE"
            FROM SYSDD.LOCKSTATISTICS
            WHERE USERGROUP IN(SELECT USERNAME
                              FROM SYSDD.USERS
                              WHERE USERMODE IN('DBA', 'SYSDBA', 'COLDUSER')
                              AND USERNAME = USERGROUP)
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON LOCKLISTSTATISTICS TO PUBLIC WITH GRANT OPTION')

    rc = sqlRC (session,
        """SELECT DESCRIPTION
        FROM SYSDD.XPARAMETERS
        WHERE DESCRIPTION = 'INSTANCE_TYPE'
        AND "VALUE" = 'LVC'""")

    if rc == 0:

        # liveCache Installation
        # ----------------------
        createReplaceView (session, 'HISTORYINFO',
            """(FILENO, FIRSTTRANS, LASTTRANS, PAGECOUNT)
            AS SELECT
                  FILE_NO, FIRST_TRANS, LAST_TRANS, PAGECOUNT
               FROM SYSDD.HISTORY_INFO
            INTERNAL""")

        stopIfSqlNotOK (session, 'GRANT SELECT ON HISTORYINFO TO PUBLIC WITH GRANT OPTION')

        createReplaceView (session, 'CONSISTENTVIEWS',
            """(CONSISTENTVIEW, OPENTRANS, OPENDATE, OPENTIME, LASTUSED)
            AS SELECT
                  CONSISTENT_VIEW, OPEN_TRANS, "DATE", "TIME", LAST_USED
               FROM SYSDD.CONSISTENTVIEWS
            INTERNAL""")

        stopIfSqlNotOK (session, 'GRANT SELECT ON CONSISTENTVIEWS TO PUBLIC WITH GRANT OPTION')

        createReplaceView (session, 'SERVERDBSTATISTICS',
            """(SERVERDBSIZE,  MAXDATAPAGENO, MAXPERM, USEDPERM,
               PCTUSEDPERM, USEDTMP, PCTUSEDTMP,
               UNUSED, PCTUNUSED, UPDATEDPERM,
               SERVERDBFULL, LOGSIZE, USEDLOG, PCTUSEDLOG,
               USEDOMSLOG, MINFREEOMSLOG,
               LOGNOTSAVED, PCTLOGNOTSAVED, LOGSINCEBACKUP,
               RESERVEDREDO,
               LOGSEGMENTSIZE, SAVEPOINTS,CHECKPOINTS)
            AS SELECT
                 SIZE, MAX_DATA_PAGE_NO, MAX_PERM_PAGES, USED_PERM_PAGES,
                 PCT_PERM_USED, USED_TEMP_PAGES, PCT_TEMP_USED,
                 UNUSED_PAGES, PCT_PAGES_UNUSED, UPDATED_PERM_PAGES,
                 SERVERDB_FULL, LOG_PAGES, USED_LOG_PAGES, PCT_LOGUSED,
                 OMS_LOG_USED, OMS_LOG_MIN_FREE,
                 LOG_NOT_SAVED, PCT_LOG_NOT_SAVED, LOG_SINCE_BACKUP,
                 RESERVED_REDO_SIZE,
                 LOG_SEGMENT_SIZE, SAVEPOINTS, CHECKPOINTS
               FROM SYSDD.SERVERDB_STATS
               WHERE USER IN(SELECT USERNAME
                             FROM SYSDD.USERS
                             WHERE USERNAME = USERGROUP
                             AND USERMODE IN('DBA', 'SYSDBA', 'COLDUSER'))
            INTERNAL""")

        stopIfSqlNotOK (session, 'GRANT SELECT ON SERVERDBSTATISTICS TO PUBLIC WITH GRANT OPTION')

        createReplaceView(session, 'OMS_MEMORY_USAGE',
	        """(TOTAL_HEAP_USAGE)
		    AS SELECT "HEAPSIZE (BYTES)"
		    FROM SYSDD.OMS_MEMORY
		    INTERNAL""")

        stopIfSqlNotOK (session, 'GRANT SELECT ON OMS_MEMORY_USAGE TO PUBLIC WITH GRANT OPTION')

        createReplaceView (session, 'MONITOR_OMS',
            """(IID, "Methodname",  "CallCnt", "AvgRuntime",
            "OMS_Deref",        "LC_Deref", "KeyDeref",
            "OMS_Store",        "LC_Store", "OMS_Delete",
            "LC_Delete",        "LC_Lock",  "LC_LogHops",
            "Exceptions",       "OutOfDateExceptions",
            "Timeouts",         "SubtransRollbacks",
            "SubtransCommits",  "MaxSubtransLevel",
            "VarObjectLoad",   "VarObjectStore",
            "AvgVarObjectSize", "OmsCacheSize",
			"MaxWaitForNewConsView", "MinWaitForNewConsView",
            "AvgWaitForNewConsView")
           AS SELECT IID, METHODNAME, CALL_CNT,
              RUNTIME / CALL_CNT,
              DEREF,
              DEREF_VIA_LC,
              DEREF_VIA_KEY,
              OMS_STORE,
              LC_STORE,
              OMS_DELETE,
              LC_DELETE,
              LC_LOCK,
              LC_LOG_HOPS,
              EXCEPTIONS,
              OUT_OF_DATE,
              TIMEOUT,
              SUBTRANS_ROLLBACK,
              SUBTRANS_COMMIT,
              MAX_SUBTRANS_LEVEL,
              LOAD_VAR_OBJ,
              STORE_VAR_OBJ,
              AVG_VAR_OBJ_SIZE,
              CACHE_SIZE,
			  NEWCONSVIEWMAXWAIT,
			  NEWCONSVIEWMINWAIT,
			  NEWCONSVIEWAVGWAIT
           FROM SYSDD.OMS_MONITOR
           INTERNAL""")

        stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_OMS TO PUBLIC WITH GRANT OPTION')

    else:
        # OLTP Installation
        # -----------------

	createReplaceView (session, 'SERVERDBSTATISTICS',
            """(SERVERDBSIZE,  MAXDATAPAGENO, MAXPERM, USEDPERM,
               PCTUSEDPERM, USEDTMP, PCTUSEDTMP,
               UNUSED, PCTUNUSED, UPDATEDPERM,
               SERVERDBFULL, LOGSIZE, USEDLOG, PCTUSEDLOG,
               LOGNOTSAVED, PCTLOGNOTSAVED, LOGSINCEBACKUP,
               RESERVEDREDO,
               LOGSEGMENTSIZE, SAVEPOINTS,CHECKPOINTS)
            AS SELECT
                 SIZE, MAX_DATA_PAGE_NO, MAX_PERM_PAGES, USED_PERM_PAGES,
                 PCT_PERM_USED, USED_TEMP_PAGES, PCT_TEMP_USED,
                 UNUSED_PAGES, PCT_PAGES_UNUSED, UPDATED_PERM_PAGES,
                 SERVERDB_FULL, LOG_PAGES, USED_LOG_PAGES, PCT_LOGUSED,
                 LOG_NOT_SAVED, PCT_LOG_NOT_SAVED, LOG_SINCE_BACKUP,
                 RESERVED_REDO_SIZE,
                 LOG_SEGMENT_SIZE, SAVEPOINTS, CHECKPOINTS
               FROM SYSDD.SERVERDB_STATS
               WHERE USER IN(SELECT USERNAME
                             FROM SYSDD.USERS
                             WHERE USERNAME = USERGROUP
                             AND USERMODE IN('DBA', 'SYSDBA', 'COLDUSER'))
            INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON SERVERDBSTATISTICS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'TABLESTATISTICS',
	"""(OWNER,TABLENAME,DESCRIPTION,CHAR_VALUE,NUMERIC_VALUE)
    AS SELECT
	 OWNER,TABLENAME,DESCRIPTION,"VALUE",NUMERIC_VALUE
       FROM SYSDD.TABLESTATISTICS
    INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON TABLESTATISTICS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'TRANSACTIONS',
	"""(SESSION,TRANSCOUNT,PROCESS,USERNAME,CONNECTDATE,
	CONNECTTIME,TERMID,
	REQTIMEOUT,LASTWRITE,LOCKMODE,LOCKSTATE,
	REQMODE,REQSTATE,APPLPROCESS,APPLNODEID)
	AS SELECT
	SESSION,TRANSCOUNT,PROCESS,USERNAME,"DATE",
	"TIME",TERMID,
	REQ_TIMEOUT,LAST_WRITE,LOCK_MODE,LOCK_STATE,
	REQ_MODE,REQ_STATE,APPL_PROCESS,APPL_NODEID
	FROM SYSDD.TRANSACTIONS
	WHERE USERNAME = USER
	OR USERGROUP IN(SELECT USERNAME
		       FROM SYSDD.USERS
		       WHERE USERMODE IN('DBA', 'SYSDBA', 'COLDUSER')
		       AND USERNAME = USERGROUP)
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON TRANSACTIONS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'USERSTATISTICS',
	"""(USERNAME,USERMODE,PERMLIMIT,PERMCOUNT,TEMPLIMIT,TEMPCOUNT)
	AS SELECT
	USERNAME,USERMODE,PERMLIMIT,PERMCOUNT,TEMPLIMIT,TEMPCOUNT
	FROM SYSDD.USERSTATISTICS
	INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON USERSTATISTICS TO PUBLIC WITH GRANT OPTION')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_CACHES')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_LOAD')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_LOCK')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_LOG')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_LONG')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_PAGES')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_ROW')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_TRANS')

    stopIfSqlNotErr (session, -4007, 'DROP PUBLIC SYNONYM MONITOR_VTRACE')

    createReplaceView (session, 'MONITOR_CACHES',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'CACHES'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_CACHES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_LOAD',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'LOAD'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_LOAD TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_LOCK',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'LOCK'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_LOCK TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_LOG',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'LOG'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_LOG TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_LONG',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'LONG'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_LONG TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_PAGES',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'PAGES'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_PAGES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_ROW',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'ROW'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_ROW TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_TRANS',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'TRANS'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_TRANS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR_VTRACE',
	"""(DESCRIPTION,"VALUE")
	AS SELECT
	DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE "TYPE" = 'VTRACE'
	AND USERGROUP IN(SELECT USERNAME
			FROM SYSDD.USERS
			WHERE USERNAME = USERGROUP
			AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR_VTRACE TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'MONITOR',
	"""("TYPE",DESCRIPTION,"VALUE")
	AS SELECT
	"TYPE",DESCRIPTION,"VALUE"
	FROM SYSDD.MONITOR
	WHERE USERGROUP IN(SELECT USERNAME
			  FROM SYSDD.USERS
			  WHERE USERNAME = USERGROUP
			  AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON MONITOR TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'DBTIMES',
	"""(RESTART_DATE, RESTART_TIME)
	AS SELECT
	"DATE", "TIME"
	FROM SYSDD.SERVERDB_STATS
	WHERE USERGROUP IN(SELECT USERNAME
			  FROM SYSDD.USERS
			  WHERE USERNAME = USERGROUP
			  AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON DBTIMES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'DBPARAMETERS',
	"""(DESCRIPTION, "VALUE")
	AS SELECT
	"DESCRIPTION", "VALUE"
	FROM SYSDD.XPARAMETERS
	WHERE USERGROUP IN(SELECT USERNAME
			  FROM SYSDD.USERS
			  WHERE USERNAME = USERGROUP
			  AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON DBPARAMETERS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'ROOTS',
	"""(TABLEID,OWNER,TABLENAME,INDEXNAME,TYPE,ROOT)
	AS SELECT
	TABLEID,OWNER,TABLENAME,INDEXNAME,TYPE,ROOT
	FROM SYSDD.ROOTS
	WHERE USERGROUP IN(OWNER,LOCALSYSDBA)
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON ROOTS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'RUNNING_COMMANDS',
	"""AS SELECT
        T1.TASKID, T2.JOB, T2.LINE,
        T1.PARSEID, T2.SQL_STATEMENT
        FROM SYSDD.RUNNING_COMMANDS T1, SYSPARSEID T2
        WHERE T1.PARSEID = T2.PARSEID
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON RUNNING_COMMANDS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'RUNNING_PARSEIDS',
	"""AS SELECT
        TASKID, PARSEID
        FROM SYSDD.RUNNING_COMMANDS
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON RUNNING_PARSEIDS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'PAGES',
	"""(OWNER,TABLENAME,DESCRIPTION,CHAR_VALUE,
            NUMERIC_VALUE,SHORT_COLUMN_PAGES)
	AS SELECT
	OWNER,TABLENAME,DESCRIPTION,"VALUE",
        NUMERIC_VALUE,SHORT_COLUMN_PAGES
	FROM SYSDD.PAGES
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON PAGES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'ESTIMATED_PAGES',
	"""(OWNER,TABLENAME,DESCRIPTION,
            ESTIMATED_PAGES,SHORT_COLUMN_PAGES)
	AS SELECT
	OWNER,TABLENAME,DESCRIPTION,
        ESTIMATED_PAGES,SHORT_COLUMN_PAGES
	FROM SYSDD.PAGES
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON ESTIMATED_PAGES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'INDEXPAGES',
	"""(OWNER,TABLENAME,INDEXNAME,DESCRIPTION,CHAR_VALUE,NUMERIC_VALUE)
	AS SELECT
	OWNER,TABLENAME,DECODE(INDEXNAME,NULL,COLUMNNAME,INDEXNAME),
        DESCRIPTION,"VALUE",NUMERIC_VALUE
	FROM SYSDD.INDEXPAGES
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON INDEXPAGES TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'TREELOCKS',
	"""("ROOT","INDEX","LEAF","PROCESS","STATE","MODE")
	AS SELECT
	DECODE ("ROOT",  2147483647, 'NIL PAGE NO', CHR("ROOT",  10)),
	DECODE ("INDEX", 2147483647, 'NIL PAGE NO', chr("INDEX", 10)),
	DECODE ("LEAF",  2147483647, 'NIL PAGE NO', chr("LEAF",  10)),
	PROCESS, STATE, MODE
	FROM SYSDD.TREELOCKS
	WHERE USER IN(SELECT USERNAME
		     FROM SYSDD.USERS
		     WHERE USERNAME = USERGROUP
		     AND USERMODE IN('DBA','SYSDBA', 'COLDUSER'))
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON TREELOCKS TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'DB_STATE',
	"""("DESCRIPTION","NUMERIC_VALUE","VALUE")
	AS SELECT
    DESCRIPTION, NUMERIC_VALUE, "VALUE"
    FROM SYSDD.SERVER_DB_STATE
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON DB_STATE TO PUBLIC WITH GRANT OPTION')

    createReplaceView (session, 'INTERNAL_STATE',
	"""("COMPONENT","DESCRIPTION","VALUE")
	AS SELECT
    COMPONENT, DESCRIPTION, "VALUE"
    FROM SYSDD.INTERNAL_STATE
	INTERNAL""")
    stopIfSqlNotOK (session, 'GRANT SELECT ON INTERNAL_STATE TO PUBLIC WITH GRANT OPTION')

# NMP added PTS 1108439

    rc = sqlRC (session,
         """SELECT PACKAGE
         FROM SYSDD.DBPROCEDURES
         WHERE OWNER = USER AND PACKAGE = 'SYS_PACKAGE'""")

    if rc == 0:
        stopIfSqlNotOK (session, 'DROP PACKAGE SYS_PACKAGE')

    stopIfSqlNotOK (session,
        """CREATE PACKAGE SYS_PACKAGE AS 'liveCache.dbpInstall.V72' INPROC""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC COPY_AND_REG_DLL IN SYS_PACKAGE EXECUTE INPROC""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC ACTIVATE_DLL IN SYS_PACKAGE EXECUTE INPROC""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC REG_DLL IN SYS_PACKAGE EXECUTE INPROC""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC FORCE_CHECKPOINT IN SYS_PACKAGE EXECUTE INPROC NOWAIT""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC WAIT_FOR_CHECKPOINT IN SYS_PACKAGE EXECUTE INPROC NOWAIT""")

    stopIfSqlNotOK (session,
        """CREATE DBPROC FORCE_AND_WAIT_FOR_CHECKPOINT IN SYS_PACKAGE EXECUTE INPROC NOWAIT""")


    repmanCmd (session, 'COMMIT')

    repmanCmd (session, 'INSTALLATION OFF')

    # End of Install



if __name__ == '__main__':
    connectAndInstall (install, "Installing tables for SYSDBA\n")


