#
# =====================================================
# @(#) SYSSET                    7.2        1999-07-29
# =====================================================
# Changes in  7.2:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *

def install (session,options):
    """Installing system table SYSSET
    """

    repmanCmd (session, 'INSTALLATION ON')

    repmanCmd (session, 'AUTOCOMMIT OFF')

    if existsTable (session, "SYSSET"):
        stopIfSqlNotOK (session, 'RENAME TABLE SYSSET TO "SET"')

    hasTmp_Set = None
    if existsTable (session, '"SET"'):
        if sqlOK (session, 'SELECT * FROM "SET"'):
            stopIfSqlNotOK (session, 'CREATE TABLE TMP_SET AS SELECT * FROM "SET"')
            hasTmp_Set = 1
        stopIfSqlNotOK (session, 'DROP TABLE "SET"')

    stopIfSqlNotOK (session, """
        CREATE TABLE "SET"
        (
        USERNAME             SYSID                   DEFAULT USER
                   CONSTRAINT SET_PK PRIMARY KEY,
        LANGUAGE             CHAR(40) ASCII NOT NULL DEFAULT 'ENG',
        NULLVALUE            CHAR(40) ASCII NOT NULL DEFAULT '?',
        DECIMALREP           CHAR(40) ASCII NOT NULL DEFAULT ' .',
        DAT                  CHAR(50) ASCII NOT NULL DEFAULT 'INTERNAL',
        TIM                  CHAR(50) ASCII NOT NULL DEFAULT 'INTERNAL'
                   CHECK TIM NOT IN('INTERNAL','EUR','JIS','USA','ISO') OR TIM = DAT,
        SEP                  CHAR(40) ASCII NOT NULL DEFAULT 'STANDARD',
        L_SEP                CHAR(40) ASCII NOT NULL DEFAULT '8'
        CHECK L_SEP >= CHR (LENGTH (SEP)),
        PRINTFORMAT          CHAR(40) ASCII NOT NULL DEFAULT 'DEFAULT',
        COPYVALUE            CHAR(40) ASCII NOT NULL DEFAULT '1',
        SYSEDITOR            CHAR(40) ASCII NOT NULL DEFAULT 'vi',
        PREFIX               CHAR(40) ASCII NOT NULL DEFAULT 'NO',
        LO_PRESENTATION      CHAR(40) ASCII NOT NULL DEFAULT 'DEFAULT',
        LOADPROT             CHAR(64) ASCII NOT NULL DEFAULT 'load.prot',
        TRANSIZE             CHAR(40) ASCII NOT NULL DEFAULT '100',
        YE_PRESENTATION      CHAR(40) ASCII NOT NULL DEFAULT 'DEFAULT',
        LT_PRES              CHAR(40) ASCII NOT NULL DEFAULT '< %1',
        LE_PRES              CHAR(40) ASCII NOT NULL DEFAULT '<= %1',
        GT_PRES              CHAR(40) ASCII NOT NULL DEFAULT '> %1',
        GE_PRES              CHAR(40) ASCII NOT NULL DEFAULT '>= %1',
        EQ_PRES              CHAR(40) ASCII NOT NULL DEFAULT '= %1',
        NE_PRES              CHAR(40) ASCII NOT NULL DEFAULT '<> %1',
        NOT_PRES             CHAR(40) ASCII NOT NULL DEFAULT '<> %1',
        IN_PRES              CHAR(40) ASCII NOT NULL DEFAULT '%1 | %2',
        BETW_PRES            CHAR(40) ASCII NOT NULL DEFAULT '%1  ..  %2',
        SOUNDS_PRES          CHAR(40) ASCII NOT NULL DEFAULT ': %1',
        DELIMITER            CHAR(40) ASCII NOT NULL DEFAULT '/',
        FILLCHAR             CHAR(40) ASCII NOT NULL DEFAULT '.',
        GRAFICCHAR           CHAR(40) ASCII NOT NULL DEFAULT '|',
        IGNORECASE           CHAR(40) ASCII NOT NULL DEFAULT 'OFF',
        ACTUALIZE            CHAR(40) ASCII NOT NULL DEFAULT 'OFF',
        QU_PRESENTATION      CHAR(40) ASCII NOT NULL DEFAULT 'DEFAULT',
        QUERYPROT            CHAR(64) ASCII NOT NULL DEFAULT 'query.prot',
        AUTOPROT             CHAR(40) ASCII NOT NULL DEFAULT 'OFF',
        PL_PRESENTATION      CHAR(40) ASCII NOT NULL DEFAULT 'DEFAULT',
        PLPROT               CHAR(64) ASCII NOT NULL DEFAULT 'sqlpl.prot',
        PRETTY               CHAR(40) ASCII NOT NULL DEFAULT 'OFF',
        NESTING              CHAR(40) ASCII NOT NULL DEFAULT '20',
        DIA_C_AREA           CHAR(40) ASCII NOT NULL DEFAULT '128000',
        DIA_V_AREA           CHAR(40) ASCII NOT NULL DEFAULT '128000',
        DIA_VERSION          CHAR(40) ASCII NOT NULL DEFAULT 'TEST',
        DIA_TARGET_LANGS     CHAR(40) ASCII NOT NULL DEFAULT '',
        TIMSTMP              CHAR(50) ASCII NOT NULL DEFAULT 'INTERNAL'
                CHECK TIMSTMP NOT IN('INTERNAL','EUR','JIS','USA','ISO') OR TIMSTMP = DAT,
        BOOL                 CHAR(40) ASCII NOT NULL DEFAULT 'TRUE      FALSE',
        SQLTIME              CHAR(40) ASCII NOT NULL DEFAULT 'OFF',
        HISTORY              CHAR(40) ASCII NOT NULL DEFAULT 'OFF'
        )
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT ALL ON "SET" TO DOMAIN')

    stopIfSqlNotOK (session, """
        CREATE VIEW SET_R
        AS SELECT *
        FROM "SET"
        WHERE USERNAME = USER OR USERNAME = SYSDBA
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON SET_R TO PUBLIC')

    stopIfSqlNotOK (session, """
        CREATE VIEW SET_W
        AS SELECT *
          FROM "SET" WHERE
          USERNAME = USER
        WITH CHECK OPTION
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT DELETE,INSERT,UPDATE ON SET_W TO PUBLIC')

    if hasTmp_Set:
        if sqlOK (session, 'SELECT TIMSTMP FROM TMP_SET'):
            if sqlOK (session, 'SELECT BOOL FROM TMP_SET'):
                stopIfSqlNotOK (session, 'INSERT "SET" SELECT * FROM TMP_SET')
        else:
            stopIfSqlNotOK (session, """
                INSERT "SET"
                  SELECT *, 'TRUE      FALSE', 'OFF', 'OFF'
                  FROM TMP_SET""")
        stopIfSqlNotOK (session, 'DROP TABLE TMP_SET')
    else:
        stopIfSqlNotOK (session, 'INSERT "SET" (USERNAME) VALUES (USER)')

    hasTmp_Print = None

    if existsTable (session, "PRINT"):
        if sqlOK (session, 'SELECT * FROM PRINT'):
            stopIfSqlNotOK (session, 'CREATE TABLE TMP_PRINT AS SELECT * FROM PRINT')
            hasTmp_Print = 1
        stopIfSqlNotOK (session, 'DROP TABLE PRINT')

    stopIfSqlNotOK (session, """
        CREATE TABLE PRINT
        (
        USERNAME     SYSID,
        FORMATNAME   CHAR(40) ASCII,
        PRINTER      CHAR(64) ASCII NOT NULL,
        PAGELENGTH   CHAR(40) ASCII NOT NULL,
        PAGEWIDTH    CHAR(40) ASCII NOT NULL,
        TOPMARGIN    CHAR(40) ASCII NOT NULL,
        BOTTOMMARGIN CHAR(40) ASCII NOT NULL,
        LEFTMARGIN   CHAR(40) ASCII NOT NULL,
        RIGHTMARGIN  CHAR(40) ASCII NOT NULL,
        NEWPAGE      CHAR(40) ASCII NOT NULL,
        CONSTRAINT PRINT_PK PRIMARY KEY (USERNAME, FORMATNAME)
        )
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT ALL ON "PRINT" TO DOMAIN')

    stopIfSqlNotOK (session, """
        CREATE VIEW PRINT_R
        AS SELECT *
        FROM PRINT
        WHERE USERNAME = USER OR USERNAME = SYSDBA
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON PRINT_R TO PUBLIC')

    stopIfSqlNotOK (session, """
        CREATE VIEW PRINT_W
        AS SELECT *
         FROM PRINT
         WHERE USERNAME = USER
        WITH CHECK OPTION
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT DELETE,INSERT,UPDATE ON PRINT_W TO PUBLIC')

    if hasTmp_Print:
        stopIfSqlNotOK (session, 'INSERT PRINT SELECT * FROM TMP_PRINT')
        stopIfSqlNotOK (session, 'DROP TABLE TMP_PRINT')
    else:
        dataLoad (session, """
    DATALOAD TABLE PRINT
        "USERNAME" USER
        "FORMATNAME" 2
        "PRINTER" 3
        "PAGELENGTH" 4
        "PAGEWIDTH" 5
        "TOPMARGIN" 6
        "BOTTOMMARGIN" 7
        "LEFTMARGIN" 8
        "RIGHTMARGIN" 9
        "NEWPAGE" 10
    INFILE *
    COMPRESSED SEPARATOR ';' DELIMITER ''""","""
    ;DEFAULT; ;65;75;0;0;0;0;NO
    ;A4; ;65;75;0;0;0;0;NO
    ;Portrait; ;68;80;5;5;10;5;NO
    ;Landscape; ;60;180;5;5;10;5;NO
    ;Large; ;68;254;5;5;10;5;NO
""")


    hasTmp_Present = None
    if existsTable (session, 'PRESENT'):
        if sqlOK (session, 'SELECT * FROM PRESENT'):
            stopIfSqlNotOK (session, 'CREATE TABLE TMP_PRESENT AS SELECT * FROM PRESENT')
            hasTmp_Present = 1
        stopIfSqlNotOK (session, 'DROP TABLE PRESENT')

    stopIfSqlNotOK (session, """
        CREATE TABLE PRESENT
        (
        USERNAME     SYSID,
        PRESENTATION CHAR(18) ASCII,
            CONSTRAINT PRESENT_PK PRIMARY KEY (USERNAME,PRESENTATION),
        ATTR_1       CHAR(5)  ASCII NOT NULL,
        FOREGR_1     CHAR(5)  ASCII NOT NULL,
        BACKGR_1     CHAR(5)  ASCII NOT NULL,
        ATTR_2       CHAR(5)  ASCII NOT NULL,
        FOREGR_2     CHAR(5)  ASCII NOT NULL,
        BACKGR_2     CHAR(5)  ASCII NOT NULL,
        ATTR_3       CHAR(5)  ASCII NOT NULL,
        FOREGR_3     CHAR(5)  ASCII NOT NULL,
        BACKGR_3     CHAR(5)  ASCII NOT NULL,
        ATTR_4       CHAR(5)  ASCII NOT NULL,
        FOREGR_4     CHAR(5)  ASCII NOT NULL,
        BACKGR_4     CHAR(5)  ASCII NOT NULL,
        ATTR_5       CHAR(5)  ASCII NOT NULL,
        FOREGR_5     CHAR(5)  ASCII NOT NULL,
        BACKGR_5     CHAR(5)  ASCII NOT NULL,
        ATTR_6       CHAR(5)  ASCII NOT NULL,
        FOREGR_6     CHAR(5)  ASCII NOT NULL,
        BACKGR_6     CHAR(5)  ASCII NOT NULL,
        ATTR_7       CHAR(5)  ASCII NOT NULL,
        FOREGR_7     CHAR(5)  ASCII NOT NULL,
        BACKGR_7     CHAR(5)  ASCII NOT NULL,
        ATTR_8       CHAR(5)  ASCII NOT NULL,
        FOREGR_8     CHAR(5)  ASCII NOT NULL,
        BACKGR_8     CHAR(5)  ASCII NOT NULL,
        ATTR_9       CHAR(5)  ASCII NOT NULL,
        FOREGR_9     CHAR(5)  ASCII NOT NULL,
        BACKGR_9     CHAR(5)  ASCII NOT NULL,
        ATTR_10      CHAR(5)  ASCII NOT NULL,
        FOREGR_10    CHAR(5)  ASCII NOT NULL,
        BACKGR_10    CHAR(5)  ASCII NOT NULL,
        ATTR_11      CHAR(5)  ASCII NOT NULL,
        FOREGR_11    CHAR(5)  ASCII NOT NULL,
        BACKGR_11    CHAR(5)  ASCII NOT NULL,
        ATTR_12      CHAR(5)  ASCII NOT NULL,
        FOREGR_12    CHAR(5)  ASCII NOT NULL,
        BACKGR_12    CHAR(5)  ASCII NOT NULL,
        ATTR_13      CHAR(5)  ASCII NOT NULL,
        FOREGR_13    CHAR(5)  ASCII NOT NULL,
        BACKGR_13    CHAR(5)  ASCII NOT NULL,
        ATTR_14      CHAR(5)  ASCII NOT NULL,
        FOREGR_14    CHAR(5)  ASCII NOT NULL,
        BACKGR_14    CHAR(5)  ASCII NOT NULL,
        ATTR_15      CHAR(5)  ASCII NOT NULL,
        FOREGR_15    CHAR(5)  ASCII NOT NULL,
        BACKGR_15    CHAR(5)  ASCII NOT NULL,
        ATTR_16      CHAR(5)  ASCII NOT NULL,
        FOREGR_16    CHAR(5)  ASCII NOT NULL,
        BACKGR_16    CHAR(5)  ASCII NOT NULL )
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT ALL ON "PRESENT" TO DOMAIN')

    stopIfSqlNotOK (session, """
        CREATE VIEW PRESENT_R
        AS SELECT *
           FROM PRESENT
           WHERE USERNAME = USER OR USERNAME = SYSDBA
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT SELECT ON PRESENT_R TO PUBLIC')

    stopIfSqlNotOK (session, """
        CREATE VIEW PRESENT_W
        AS SELECT *
          FROM PRESENT
        WHERE USERNAME = USER
        WITH CHECK OPTION
        INTERNAL""")

    stopIfSqlNotOK (session, 'GRANT DELETE,INSERT,UPDATE ON PRESENT_W TO PUBLIC')

    if hasTmp_Present:
        stopIfSqlNotOK (session, 'INSERT PRESENT SELECT * FROM TMP_PRESENT')
        stopIfSqlNotOK (session, 'DROP TABLE TMP_PRESENT')

    # In any case the following presentations will be loaded. Any presentation
    # with the same name will not be overwritten.

    dataLoad (session, """
     DATALOAD TABLE PRESENT
     IGNORE DUPLICATES
    "USERNAME" user
    "PRESENTATION" 2
    "ATTR_1"   3
    "FOREGR_1" 4
    "BACKGR_1" 5
    "ATTR_2"   6
    "FOREGR_2" 7
    "BACKGR_2" 8
    "ATTR_3"   9
    "FOREGR_3" 10
    "BACKGR_3" 11
    "ATTR_4"   12
    "FOREGR_4" 13
    "BACKGR_4" 14
    "ATTR_5"   15
    "FOREGR_5" 16
    "BACKGR_5" 17
    "ATTR_6"   18
    "FOREGR_6" 19
    "BACKGR_6" 20
    "ATTR_7"   21
    "FOREGR_7" 22
    "BACKGR_7" 23
    "ATTR_8"   24
    "FOREGR_8" 25
    "BACKGR_8" 26
    "ATTR_9"   27
    "FOREGR_9" 28
    "BACKGR_9" 29
    "ATTR_10"  30
    "FOREGR_10" 31
    "BACKGR_10" 32
    "ATTR_11"   33
    "FOREGR_11" 34
    "BACKGR_11" 35
    "ATTR_12"   36
    "FOREGR_12" 37
    "BACKGR_12" 38
    "ATTR_13"   39
    "FOREGR_13" 40
    "BACKGR_13" 41
    "ATTR_14"   42
    "FOREGR_14" 43
    "BACKGR_14" 44
    "ATTR_15"   45
    "FOREGR_15" 46
    "BACKGR_15" 47
    "ATTR_16"   48
    "FOREGR_16" 49
    "BACKGR_16" 50
    INFILE *
COMPRESSED SEPARATOR ';' DELIMITER ''""",
""";DEFAULT;0;1;6;1;1;6;2;1;6;10;1;6;1;5;6;1;1;3;0;8;6;5;1;6;7;1;6;0;1;6;2;1;6;0;1;6;2;1;6;4;1;6;16;1;6;0;1;6
;AIX;0;1;6;1;1;6;2;1;6;10;1;6;1;5;6;1;1;3;0;8;6;7;1;6;5;1;6;0;1;6;2;1;6;1;2;6;2;1;6;4;1;6;16;1;6;0;1;6
;BLACK;0;1;2;1;1;2;1;7;2;11;7;5;1;4;2;3;3;1;1;8;2;1;5;2;3;6;5;1;1;2;3;6;1;0;1;2;3;6;1;1;5;2;16;2;2;0;1;2
;HP9_SUN;0;1;6;1;1;6;2;1;6;10;1;6;1;5;6;1;1;3;0;8;6;5;1;6;7;1;6;0;1;6;2;1;6;0;6;6;2;1;6;4;1;6;16;1;6;0;1;6
;NETTERM;0;1;2;0;1;2;1;7;2;2;7;5;0;4;2;3;3;1;0;8;2;4;5;2;6;6;5;0;1;2;2;6;1;0;1;2;2;6;1;4;5;2;16;2;2;0;1;2
;WHITE;1;2;1;0;2;1;2;8;6;10;8;6;1;5;1;3;3;1;1;2;1;1;1;1;3;6;1;0;6;1;2;6;1;1;2;1;3;6;1;4;1;1;16;1;1;0;1;1
;XTERM;1;2;1;0;2;1;2;8;6;10;8;6;1;6;1;3;3;1;0;2;1;1;6;1;3;1;6;0;2;1;0;8;6;0;8;1;3;6;6;4;1;1;16;1;1;0;1;1
""")

    repmanCmd (session, 'COMMIT')

    repmanCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)

